==> visual-third-party-2.1-sources.jar: com/tenqube/visual_third/entity/Transaction.java <==
package com.tenqube.visual_third.entity;

public class Transaction {

    private int id;
    private long identifier;
    private int cardId;
    private int userCategoryId;
    private int companyId;
    private String franchise;
    private int categoryCode;

    private String spentDate;
    private String finishDate;
    private double lat;
    private double lng;
    private double spentMoney;
    private int installmentCnt;
    private String keyword;
    private String searchKeyword;
    private int repeatType;
    private String currency;
    private boolean isDeleted;
    private int dwType;

    private String sender;
    private String fullSms;
    private String smsDate;
    private int smsType;
    private int regId;

    private boolean isOffset;
    private boolean isCustom;
    private boolean isUserUpdate;
    private boolean isUpdateAll;

    private String memo;
    private String classCode;

    private boolean isSynced;

    public Transaction(int id, long identifier, int cardId, int userCategoryId, int companyId, String franchise, int categoryCode, String spentDate, String finishDate, double lat, double lng, double spentMoney, int installmentCnt, String keyword, String searchKeyword, int repeatType, String currency, boolean isDeleted, int dwType, String sender, String fullSms, String smsDate, int smsType, int regId, boolean isOffset, boolean isCustom, boolean isUserUpdate, boolean isUpdateAll, String memo, String classCode, boolean isSynced) {
        this.id = id;
        this.identifier = identifier;
        this.cardId = cardId;
        this.userCategoryId = userCategoryId;
        this.companyId = companyId;
        this.franchise = franchise;
        this.categoryCode = categoryCode;
        this.spentDate = spentDate;
        this.finishDate = finishDate;
        this.lat = lat;
        this.lng = lng;
        this.spentMoney = spentMoney;
        this.installmentCnt = installmentCnt;
        this.keyword = keyword;
        this.searchKeyword = searchKeyword;
        this.repeatType = repeatType;
        this.currency = currency;
        this.isDeleted = isDeleted;
        this.dwType = dwType;
        this.sender = sender;
        this.fullSms = fullSms;
        this.smsDate = smsDate;
        this.smsType = smsType;
        this.regId = regId;
        this.isOffset = isOffset;
        this.isCustom = isCustom;
        this.isUserUpdate = isUserUpdate;
        this.isUpdateAll = isUpdateAll;
        this.memo = memo;
        this.classCode = classCode;
        this.isSynced = isSynced;
    }

//    public Transaction(tenqube.parser.model.Transaction parsedTran, int cardId, int userCateId) {
//        if(parsedTran == null) return;
//
//        this.identifier = parsedTran.identifier;
//        this.cardId = cardId;
//        this.userCategoryId = userCategoryId;
//        this.companyId = companyId;
//        this.franchise = franchise;
//        this.categoryCode = categoryCode;
//        this.spentDate = spentDate;
//        this.finishDate = finishDate;
//        this.lat = lat;
//        this.lng = lng;
//        this.spentMoney = spentMoney;
//        this.installmentCnt = installmentCnt;
//        this.keyword = keyword;
//        this.searchKeyword = searchKeyword;
//        this.repeatType = repeatType;
//        this.currency = currency;
//        this.isDeleted = isDeleted;
//        this.dwType = dwType;
//        this.sender = sender;
//        this.fullSms = fullSms;
//        this.smsDate = smsDate;
//        this.smsType = smsType;
//        this.regId = regId;
//        this.isOffset = isOffset;
//        this.isCustom = isCustom;
//        this.isUserUpdate = isUserUpdate;
//        this.isUpdateAll = isUpdateAll;
//        this.memo = memo;
//        this.classCode = classCode;
//        this.isSynced = isSynced;
//    }


    public int getId() {
        return id;
    }

    public long getIdentifier() {
        return identifier;
    }

    public int getCardId() {
        return cardId;
    }

    public int getUserCategoryId() {
        return userCategoryId;
    }

    public int getCompanyId() {
        return companyId;
    }

    public String getFranchise() {
        return franchise;
    }

    public int getCategoryCode() {
        return categoryCode;
    }

    public String getSpentDate() {
        return spentDate;
    }

    public String getFinishDate() {
        return finishDate;
    }

    public double getLat() {
        return lat;
    }

    public double getLng() {
        return lng;
    }

    public double getSpentMoney() {
        return spentMoney;
    }

    public int getInstallmentCnt() {
        return installmentCnt;
    }

    public String getKeyword() {
        return keyword;
    }

    public String getSearchKeyword() {
        return searchKeyword;
    }

    public int getRepeatType() {
        return repeatType;
    }

    public String getCurrency() {
        return currency;
    }

    public boolean isDeleted() {
        return isDeleted;
    }

    public int getDwType() {
        return dwType;
    }

    public String getSender() {
        return sender;
    }

    public String getFullSms() {
        return fullSms;
    }

    public String getSmsDate() {
        return smsDate;
    }

    public int getSmsType() {
        return smsType;
    }

    public int getRegId() {
        return regId;
    }

    public boolean isOffset() {
        return isOffset;
    }

    public boolean isCustom() {
        return isCustom;
    }

    public boolean isUserUpdate() {
        return isUserUpdate;
    }

    public boolean isUpdateAll() {
        return isUpdateAll;
    }

    public String getMemo() {
        return memo;
    }

    public String getClassCode() {
        return classCode;
    }

    public boolean isSynced() {
        return isSynced;
    }

    @Override
    public String toString() {
        return "Transaction{" +
                "id=" + id +
                ", identifier=" + identifier +
                ", cardId=" + cardId +
                ", userCategoryId=" + userCategoryId +
                ", companyId=" + companyId +
                ", franchise='" + franchise + '\'' +
                ", categoryCode=" + categoryCode +
                ", spentDate='" + spentDate + '\'' +
                ", finishDate='" + finishDate + '\'' +
                ", lat=" + lat +
                ", lng=" + lng +
                ", spentMoney=" + spentMoney +
                ", installmentCnt=" + installmentCnt +
                ", keyword='" + keyword + '\'' +
                ", searchKeyword='" + searchKeyword + '\'' +
                ", repeatType=" + repeatType +
                ", currency='" + currency + '\'' +
                ", isDeleted=" + isDeleted +
                ", dwType=" + dwType +
                ", sender='" + sender + '\'' +
                ", fullSms='" + fullSms + '\'' +
                ", smsDate='" + smsDate + '\'' +
                ", smsType=" + smsType +
                ", regId=" + regId +
                ", isOffset=" + isOffset +
                ", isCustom=" + isCustom +
                ", isUserUpdate=" + isUserUpdate +
                ", isUpdateAll=" + isUpdateAll +
                ", memo='" + memo + '\'' +
                ", classCode='" + classCode + '\'' +
                ", isSynced=" + isSynced +
                '}';
    }
}

==> visual-third-party-3.2-sources.jar: com/tenqube/visual_third/entity/Transaction.java <==
package com.tenqube.visual_third.entity;

public class Transaction {

    private int id;
    private long identifier;
    private int cardId;
    private int userCategoryId;
    private int companyId;
    private String franchise;
    private int categoryCode;

    private String spentDate;
    private String finishDate;
    private double lat;
    private double lng;
    private double spentMoney;
    private double oriSpentMoney;
    private int installmentCnt;
    private String keyword;
    private String searchKeyword;
    private int repeatType;
    private String currency;
    private boolean isDeleted;
    private int dwType;

    private String sender;
    private String fullSms;
    private String smsDate;
    private int smsType;
    private int regId;

    private boolean isOffset;
    private boolean isCustom;
    private boolean isUserUpdate;
    private boolean isUpdateAll;

    private String memo;
    private String classCode;

    private boolean isSynced;

    public Transaction(int id, long identifier, int cardId, int userCategoryId, int companyId, String franchise, int categoryCode, String spentDate, String finishDate, double lat, double lng, double spentMoney, double oriSpentMoney, int installmentCnt, String keyword, String searchKeyword, int repeatType, String currency, boolean isDeleted, int dwType, String sender, String fullSms, String smsDate, int smsType, int regId, boolean isOffset, boolean isCustom, boolean isUserUpdate, boolean isUpdateAll, String memo, String classCode, boolean isSynced) {
        this.id = id;
        this.identifier = identifier;
        this.cardId = cardId;
        this.userCategoryId = userCategoryId;
        this.companyId = companyId;
        this.franchise = franchise;
        this.categoryCode = categoryCode;
        this.spentDate = spentDate;
        this.finishDate = finishDate;
        this.lat = lat;
        this.lng = lng;
        this.spentMoney = spentMoney;
        this.oriSpentMoney = oriSpentMoney;
        this.installmentCnt = installmentCnt;
        this.keyword = keyword;
        this.searchKeyword = searchKeyword;
        this.repeatType = repeatType;
        this.currency = currency;
        this.isDeleted = isDeleted;
        this.dwType = dwType;
        this.sender = sender;
        this.fullSms = fullSms;
        this.smsDate = smsDate;
        this.smsType = smsType;
        this.regId = regId;
        this.isOffset = isOffset;
        this.isCustom = isCustom;
        this.isUserUpdate = isUserUpdate;
        this.isUpdateAll = isUpdateAll;
        this.memo = memo;
        this.classCode = classCode;
        this.isSynced = isSynced;
    }



    public int getId() {
        return id;
    }

    public long getIdentifier() {
        return identifier;
    }

    public int getCardId() {
        return cardId;
    }

    public int getUserCategoryId() {
        return userCategoryId;
    }

    public int getCompanyId() {
        return companyId;
    }

    public String getFranchise() {
        return franchise;
    }

    public int getCategoryCode() {
        return categoryCode;
    }

    public String getSpentDate() {
        return spentDate;
    }

    public String getFinishDate() {
        return finishDate;
    }

    public double getLat() {
        return lat;
    }

    public double getLng() {
        return lng;
    }

    public double getSpentMoney() {
        return spentMoney;
    }

    public double getOriSpentMoney() {
        return oriSpentMoney;
    }

    public int getInstallmentCnt() {
        return installmentCnt;
    }

    public String getKeyword() {
        return keyword;
    }

    public String getSearchKeyword() {
        return searchKeyword;
    }

    public int getRepeatType() {
        return repeatType;
    }

    public String getCurrency() {
        return currency;
    }

    public boolean isDeleted() {
        return isDeleted;
    }

    public int getDwType() {
        return dwType;
    }

    public String getSender() {
        return sender;
    }

    public String getFullSms() {
        return fullSms;
    }

    public String getSmsDate() {
        return smsDate;
    }

    public int getSmsType() {
        return smsType;
    }

    public int getRegId() {
        return regId;
    }

    public boolean isOffset() {
        return isOffset;
    }

    public boolean isCustom() {
        return isCustom;
    }

    public boolean isUserUpdate() {
        return isUserUpdate;
    }

    public boolean isUpdateAll() {
        return isUpdateAll;
    }

    public String getMemo() {
        return memo;
    }

    public String getClassCode() {
        return classCode;
    }

    public boolean isSynced() {
        return isSynced;
    }

    @Override
    public String toString() {
        return "Transaction{" +
                "id=" + id +
                ", identifier=" + identifier +
                ", cardId=" + cardId +
                ", userCategoryId=" + userCategoryId +
                ", companyId=" + companyId +
                ", franchise='" + franchise + '\'' +
                ", categoryCode=" + categoryCode +
                ", spentDate='" + spentDate + '\'' +
                ", finishDate='" + finishDate + '\'' +
                ", lat=" + lat +
                ", lng=" + lng +
                ", spentMoney=" + spentMoney +
                ", installmentCnt=" + installmentCnt +
                ", keyword='" + keyword + '\'' +
                ", searchKeyword='" + searchKeyword + '\'' +
                ", repeatType=" + repeatType +
                ", currency='" + currency + '\'' +
                ", isDeleted=" + isDeleted +
                ", dwType=" + dwType +
                ", sender='" + sender + '\'' +
                ", fullSms='" + fullSms + '\'' +
                ", smsDate='" + smsDate + '\'' +
                ", smsType=" + smsType +
                ", regId=" + regId +
                ", isOffset=" + isOffset +
                ", isCustom=" + isCustom +
                ", isUserUpdate=" + isUserUpdate +
                ", isUpdateAll=" + isUpdateAll +
                ", memo='" + memo + '\'' +
                ", classCode='" + classCode + '\'' +
                ", isSynced=" + isSynced +
                '}';
    }
}
